@@ -4,7 +4,7 @@
 
 # flake8: noqa
 
-from . import aa, automation, misc, noise, scale, descale, util
+from . import aa, automation, misc, noise, scale, denoise, descale, util
 from .aa import *
 from .automation import *
 from .auto.convert import *
@@ -12,4 +12,5 @@ from .misc import *
 from .noise import *
 from .scale import *
 from .descale import *
+from .denoise import *
 from .util import *
